TITLE 'Typical blood cell file for cancer adaptation (requires include file defns)'

SELECT
!  print(MATRIX)
!  print(GRID)
!  reorder = off
!  scaling = off
  errlim = 0.01
!  overshoot = 1e-6
!  gridlimit = 1
!  vandenberg = on
!  mergedist = 0.0001
!  precondition = Off
  diprecon = on
!  nonlinear = Off
!  linupdate = 100
  iterate = 1e6
!  changelim = 0.01
!  regrid = off
  threads = 2
!  upfactor = 10
!  direct lapack

  #include 'm_addl_select.txt'

COORDINATES cartesian2

VARIABLES
  u(1.5)
  v(1.5)
  p(1)

GLOBAL VARIABLES
  #include 'm_global_variables.txt'
  #include 'm_p_global_variables.txt'
!  pleft

DEFINITIONS    { parameter definitions }
  fade_in_globs = 0

  !!  General system information
  #include 'm_system_parameters.txt'

  !  Lubrication terms on/off/staged
  #include 'm_lubon.txt'

!!  Other system information
!  Fluid viscosity
  mu = 1

!!  Definitions for boundary of domain
  w0 = yb[3]-yb[2]!
  Q0 = v_char*w0
  !Q0 = 8

!  Speed definitions
  speed2 = u^2+v^2
  speed = sqrt(speed2)

!  Compressibility term and related penalty
  e = dx(u)+dy(v)
  penalty = 100{*mu/lengthscale^2}

!  Stress tensor
  sigma11 = 2*mu*dx(u)-p
  sigma21 = mu*(dy(u)+dx(v))
  sigma12 = mu*(dx(v)+dy(u))
  sigma22 = 2*mu*dy(v)-p

!!  Forces on the membrane
  !  General forces
  sn = vector(normal(sigma11,sigma12),normal(sigma21,sigma22))

  !!  Cell information
  #include 'm_cell_info.txt'
  #include "m_incompressibility.txt"

  !  Initial conditions
  !transfermesh('transfer.dat',uini,vini,pini)
  !  Use below instead if we don't have a transfer.dat file from a previous run
  ! uini = 6*Q0/w0^3*(w0^2/4-y^2) vini = 0 pini = 1

!  Phase in the BCs
  static = 1

!  Pressure drop calculated from experiments and flexpde, see Cancer_Cell_In_Microchannel_Pres_Calc
!  deltap = 111.75! Using 2 microliter/min flow rate in microfluidic device
!  deltap = 316 ! Using predicted 3.5 mm/sec inlet speed for 5 micoliter/min flow rate through microfluidic device

INITIAL VALUES
{  u = 6*Q0/w0^3*(w0^2/4-y^2)
  v = 0
  p = 1}
{  u = uini
  v = vini
  p = pini
  #include 'm_glob_initial_vals.txt'}
!  pleft = line_integral(pini,'left_end')
!  resolve(p)

EQUATIONS        { PDE's, one for each variable }
{   u:   dx(sigma11) + dy(sigma12) = 0
   v:   dx(sigma21) + dy(sigma22) = 0}
!  Equivalent equations when incompressibility holds but for some reason fpde likes the ones below better
   u:  mu*div(grad(u)) - dx(p) = 0!*(u*dx(u) + v*dy(u))
   v:  mu*div(grad(v)) - dy(p) = 0!*(u*dx(v) + v*dy(v))
   p:   div(grad(p)) = (1/max(k,.01))*penalty*e
  #include 'm_global_equations.txt'
!  Line integral along outside of cell integrates to 0
  #include 'm_pressure_constraint.txt'
!  Pressure chosen so that dA/dt of the cell is 0...because the time integration
!  can lead to areas that drift from Aref, we include a weak decay term to keep
!  A_01 near Aref
!  pleft: dAdt_01 = 1e-3*(1-A_01/Aref)
!  resolve(k)

CONSTRAINTS    { Integral constraints }
!  #include 'm_pressure_constraint.txt'
!  line_integral(p,'right_end') = 0
!  line_integral(p,'cell_01_01') = 0

BOUNDARIES       { The domain definition }
  REGION 1       { For each material region }
    START(xb[1],yb[1]) value(u) = 0 value(v) = 0 nobc(p) line to (xb[2],yb[2]) 
    START 'right_end' (xb[2],yb[2]) value(u) = 6*Q0/w0^3*(w0^2/4-y^2) nobc(v) natural(p) = -12*mu*Q0/w0^3 line to (xb[3],yb[3])
    START (xb[3],yb[3]) value(u) = 0 value(v) = 0 line to (xb[4],yb[4]) 
    START 'left_end' (xb[4],yb[4]) nobc(u) nobc(v) value(p) = pright line to (xb[1],yb[1])

  REGION 2
    mu = mufi
    #include 'm_cell_boundaries.txt'

!    feature start (-1000,0) line to (1000,0)

{ feature
  start ((-w0/2+0)/4,-w0/2) line to ((w0/2+0)/4,w0/2)}

! TIME 0 TO 1    { if time dependent }
MONITORS         { show progress }
  CONTOUR(u)
  CONTOUR(v)
  CONTOUR(p)
{  CONTOUR(uini)
  CONTOUR(vini)
  CONTOUR(pini)}
  CONTOUR(dx(p))
  CONTOUR(u) zoom(xm_01-15,-15,30,30)
  CONTOUR(v) zoom(xm_01-15,-15,30,30)
  CONTOUR(p) zoom(xm_01-15,-15,30,30)
  CONTOUR(dx(p)) zoom(xm_01-15,-15,30,30)
  GRID(x,y) zoom(xm_01-15,-15,30,30)
{  CONTOUR(u) zoom(-170,-10,20,20)
  CONTOUR(v) zoom(-170,-10,20,20)
  CONTOUR(p) zoom(-170,-10,20,20)
  CONTOUR(dx(p)) zoom(-170,-10,20,20)
  CONTOUR(u) zoom(150,-10,20,20)
  CONTOUR(v) zoom(150,-10,20,20)
  CONTOUR(p) zoom(150,-10,20,20)
  CONTOUR(dx(p)) zoom(150,-10,20,20)}
  vector(vector(u,v)) zoom(xm_01-15,-15,30,30) points = (30,30)
  contour(k) zoom(xm_01-15,-15,30,30)
{  elevation(u,uini,6*Q0/w0^3*(w0^2/4-y^2)) from (xb[5],yb[5]) to (xb[6],yb[6])
  elevation(u,uini,6*Q0/w0^3*(w0^2/4-y^2)) from (xb[10],yb[10]) to (xb[1],yb[1])
  elevation(v,vini,0) from (xb[5],yb[5]) to (xb[6],yb[6])
  elevation(v,vini,0) from (xb[10],yb[10]) to (xb[1],yb[1])
  elevation(p,pini) from (xb[5],yb[5]) to (xb[6],yb[6])
  elevation(p,pini) from (xb[10],yb[10]) to (xb[1],yb[1])
  elevation(dx(p),-12*Q0*mu/w0^3) from (xb[5],yb[5]) to (xb[6],yb[6])
  elevation(dx(p),-12*Q0*mu/w0^3) from (xb[10],yb[10]) to (xb[1],yb[1])}

  #include 'm_summary_report.txt'

PLOTS            { save result displays }
  CONTOUR(u)
  CONTOUR(v)
  CONTOUR(p)
{  CONTOUR(uini)
  CONTOUR(vini)
  CONTOUR(pini)}
  CONTOUR(dx(p))
  CONTOUR(u) zoom(xm_01-15,-15,30,30)
  CONTOUR(v) zoom(xm_01-15,-15,30,30)
  CONTOUR(p) zoom(xm_01-15,-15,30,30)
  CONTOUR(dx(p)) zoom(xm_01-15,-15,30,30)
  GRID(x,y) zoom(xm_01-15,-15,30,30)
{  CONTOUR(u) zoom(-170,-10,20,20)
  CONTOUR(v) zoom(-170,-10,20,20)
  CONTOUR(p) zoom(-170,-10,20,20)
  CONTOUR(dx(p)) zoom(-170,-10,20,20)
  CONTOUR(u) zoom(150,-10,20,20)
  CONTOUR(v) zoom(150,-10,20,20)
  CONTOUR(p) zoom(150,-10,20,20)
  CONTOUR(dx(p)) zoom(150,-10,20,20)}
  vector(vector(u,v)) zoom(xm_01-15,-15,30,30) points = (30,30)
  contour(k) zoom(xm_01-15,-15,30,30)
{  elevation(u,uini,6*Q0/w0^3*(w0^2/4-y^2)) from (xb[5],yb[5]) to (xb[6],yb[6])
  elevation(u,uini,6*Q0/w0^3*(w0^2/4-y^2)) from (xb[10],yb[10]) to (xb[1],yb[1])
  elevation(v,vini,0) from (xb[5],yb[5]) to (xb[6],yb[6])
  elevation(v,vini,0) from (xb[10],yb[10]) to (xb[1],yb[1])
  elevation(p,pini) from (xb[5],yb[5]) to (xb[6],yb[6])
  elevation(p,pini) from (xb[10],yb[10]) to (xb[1],yb[1])
  elevation(dx(p),-12*Q0*mu/w0^3) from (xb[5],yb[5]) to (xb[6],yb[6])
  elevation(dx(p),-12*Q0*mu/w0^3) from (xb[10],yb[10]) to (xb[1],yb[1])}

  #include 'm_summary_report.txt'

  summary export file = "success.txt"
    report(1)

  transfer(u,v,p) file = 'transfer.dat'
END